<template>
  <div class="container_plan echart" id="mychart" :style="myChartStyle">
    <Echart
      :options="option"
      id="bottomLeftChart"
      class="echarts_bottom"
    ></Echart>
  </div>
</template>
  
  <script>
import { currentGET } from "api/modules";
import { Floorfault } from "@/api/http.js";
import axios from "axios";
export default {
  data() {
    return {
      isInterval: false,
      myChartStyle: { float: "left", width: "100%", height: "250px" },
      option: {
        tooltip: {
          trigger: "axis",
          backgroundColor: "rgba(0,0,0,.6)",
          borderColor: "rgba(147, 235, 248, .8)",
          textStyle: {
            color: "#FFF",
          },
        },
        xAxis: {
          name: "单位:天",
          nameTextStyle: {
            color: ["#B4B4B4"],
            padding: [0, 0, 0, -10],
            fontSize: 14,
          },
          min: 0,
          max: 30,
          axisLine: {
            lineStyle: {
              color: "#B4B4B4",
            },
          },
          data: [
            
          ],
        },
        legend: {
          // 图例
          data: ["入库量", "出库量"],
          bottom: "0%",
          textStyle: {
            color: "#ffffff",
            fontSize: 18,
          },
        },
        yAxis: [
          {
            name: "单位:个",
            nameTextStyle: {
              color: "#B4B4B4",
              nameLocation: "start",
              padding: [0, 0, 12, -20],
              fontSize: 14,
            },
            axisLine: {
              lineStyle: {
                color: "#B4B4B4",
              },
            },
          },
        ],
        series: [
          {
            name: "入库量",
            data: [
              50, 80, 50, 72, 75, 78, 72, 70, 80, 76, 78, 74, 50, 80, 50, 72,
              75, 78, 72, 70, 80, 76, 78, 74, 50, 80, 50, 72, 75, 78,
            ],
            type: "line", // 类型设置为折线图
            label: {
              position: "top",
              textStyle: {
                fontSize: 14,
              },
            },
          },
          {
            name: "出库量",
            data: [
              0, 11, 9, 17, 14, 13, 14, 9, 17, 14, 13, 14, 0, 11, 9, 17, 14, 13,
              14, 9, 17, 14, 13, 14, 0, 11, 9, 17, 14, 13,
            ],
            type: "line", // 类型设置为折线图
            label: {
              position: "top",
              textStyle: {
                fontSize: 14,
              },
            },
          },
        ],
      },
    };
  },
  mounted() {
    this.$nextTick((x) => {
      this.getData();
    });
  },
  beforeDestroy() {
    this.clearData();
  },
  methods: {
    clearData() {
      if (this.timer) {
        clearInterval(this.timer);
        this.timer = null;
      }
    },
    getData() {
      axios.post("http://192.168.12.189:8098/api/Dt_taskinfo/GetPlanRealData",null)
        .then((res) => {
          this.init(res);
        })
        .catch((res) => {
        });
      if (!this.isInterval) {
        this.isInterval = true;
        this.timer = setInterval(() => {
          this.$nextTick((x) => {
            this.getData();
          });
        }, 10000);
      }
    },
    init(val) {
      console.log('123')
      console.log(val);
      this.option={
        tooltip: {
          trigger: "axis",
          backgroundColor: "rgba(0,0,0,.6)",
          borderColor: "rgba(147, 235, 248, .8)",
          textStyle: {
            color: "#FFF",
          },
        },
        xAxis: {
          name: "单位:天",
          nameTextStyle: {
            color: ["#B4B4B4"],
            padding: [0, 0, 0, -10],
            fontSize: 14,
          },
          min: 0,
          max: 6,
          axisLine: {
            lineStyle: {
              color: "#B4B4B4",
            },
          },
          data: [
          val[0].datetime,
          val[1].datetime,
          val[2].datetime,
          val[3].datetime,
          val[4].datetime,
          val[5].datetime,
          val[6].datetime,
        ], //获取该月的天数
        },
        legend: {
          // 图例
          data: ["入库量", "出库量"],
          bottom: "0%",
          textStyle: {
            color: "#ffffff",
            fontSize: 18,
          },
        },
        yAxis: [
          {
            name: "单位:个",
            nameTextStyle: {
              color: "#B4B4B4",
              nameLocation: "start",
              padding: [0, 0, 12, -20],
              fontSize: 14,
            },
            axisLine: {
              lineStyle: {
                color: "#B4B4B4",
              },
            },
          },
        ],
        series: [
          {
            name: "入库量", //获取计划产量
            data: [
          val[0].qty,
          val[1].qty,
          val[2].qty,
          val[3].qty,
          val[4].qty,
          val[5].qty,
          val[6].qty,
        ], 
            type: "line", // 类型设置为折线图
            label: {
              position: "top",
              textStyle: {
                fontSize: 14,
              },
            },
          },
          {
            name: "出库量",
            data: [
          val[0].qty2,
          val[1].qty2,
          val[2].qty2,
          val[3].qty2,
          val[4].qty2,
          val[5].qty2,
          val[6].qty2,
        ], 
            type: "line", // 类型设置为折线图
            label: {
              position: "top",
              textStyle: {
                fontSize: 14,
              },
            },
          },
        ],
      }
    },
  },
};
</script>
  <style lang='scss' scoped>
.container_plan {
  width: 100%;
  height: 100%;
}
</style>